@@ -1,4 +1,4 @@
-/* $Id: thread.cpp 83687 2013-02-08 12:50:49Z fmehnert $ */
+/* $Id: thread.cpp 86599 2013-06-20 09:40:27Z fmehnert $ */
 /** @file
  * IPRT - Threads, common routines.
  */
@@ -185,6 +185,20 @@ DECLHIDDEN(int) rtThreadInit(void)
 }
 
 
+#ifdef IN_RING3
+/**
+ * Called when IPRT was first initialized in unobtrusive mode and later changed
+ * to obtrustive.
+ *
+ * This is only applicable in ring-3.
+ */
+DECLHIDDEN(void) rtThreadReInitObtrusive(void)
+{
+    rtThreadNativeReInitObtrusive();
+}
+#endif
+
+
 /**
  * Terminates the thread database.
  */
