@@ -1,10 +1,10 @@
-/* $Id: thread-r0drv-linux.c 66942 2010-10-22 14:06:43Z michael $ */
+/* $Id: thread-r0drv-linux.c 83687 2013-02-08 12:50:49Z fmehnert $ */
 /** @file
  * IPRT - Threads, Ring-0 Driver, Linux.
  */
 
 /*
- * Copyright (C) 2006-2007 Oracle Corporation
+ * Copyright (C) 2006-2011 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -57,7 +57,7 @@ RTDECL(RTNATIVETHREAD) RTThreadNativeSelf(void)
 RT_EXPORT_SYMBOL(RTThreadNativeSelf);
 
 
-RTDECL(int) RTThreadSleep(RTMSINTERVAL cMillies)
+static int rtR0ThreadLnxSleepCommon(RTMSINTERVAL cMillies)
 {
     long cJiffies = msecs_to_jiffies(cMillies);
     set_current_state(TASK_INTERRUPTIBLE);
@@ -66,9 +66,22 @@ RTDECL(int) RTThreadSleep(RTMSINTERVAL cMillies)
         return VINF_SUCCESS;
     return VERR_INTERRUPTED;
 }
+
+
+RTDECL(int) RTThreadSleep(RTMSINTERVAL cMillies)
+{
+    return rtR0ThreadLnxSleepCommon(cMillies);
+}
 RT_EXPORT_SYMBOL(RTThreadSleep);
 
 
+RTDECL(int) RTThreadSleepNoLog(RTMSINTERVAL cMillies)
+{
+    return rtR0ThreadLnxSleepCommon(cMillies);
+}
+RT_EXPORT_SYMBOL(RTThreadSleepNoLog);
+
+
 RTDECL(bool) RTThreadYield(void)
 {
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 4, 20)
